@@ -23,6 +23,7 @@
 import os
 import sys
 import shutil
+import pexpect
 
 #import xorgconfig
 import XKit
@@ -47,15 +48,20 @@ class VNCHandler:
             self.xorg_conf = xutils.XUtils()
 
     def create_password(self,password):
-        if not os.path.exists("/root/.vnc"):
-            os.mkdir("/root/.vnc")
-        elif os.path.exists("/root/.vnc/passwd"):
-            print "Copying /root/.vnc/passwd to /root/.vnc/passwd.old"
-            shutil.copy("/root/.vnc/passwd","/root/.vnc/passwd.old")
-        #Create password using expect
-        os.system(SCRIPTDIR + "/create_vnc_passwd " + password)
-        #let it be readale by anyone doing this
-        os.chmod("/root/.vnc/passwd",0664)
+        home = os.environ['HOME']
+        if not os.path.exists(home + "/.vnc"):
+            os.mkdir(home + "/.vnc")
+        elif os.path.exists(home + "/.vnc/passwd"):
+            print "Copying ~/.vnc/passwd to ~/.vnc/passwd.old"
+            shutil.copy(home + "/.vnc/passwd",home + "/.vnc/passwd.old")
+        #Create password using pexpect
+	command_handler = pexpect.spawn('vncpasswd ' + home + '/.vnc/passwd')
+	command_handler.expect('Password:',timeout=-1)
+	command_handler.sendline(password)
+	command_handler.expect('Verify:',timeout=-1)
+	command_handler.sendline(password)
+	command_handler.expect(pexpect.EOF,timeout=-1)
+	command_handler.close()
 
     def toggle_xorg(self,enable):
         """Adds necessary lines for enabling VNC upon the next boot"""
